@@ -1,6 +1,6 @@
 import dis
 
-from wedeliver_core.wedeliver_core.helpers.get_callback import get_callback
+from wedeliver_core.helpers.get_callback import get_callback
 
 
 def get_embedded_function(function):
